@@ -1,5 +1,5 @@
 package App::Oozie::Deploy;
-$App::Oozie::Deploy::VERSION = '0.005';
+$App::Oozie::Deploy::VERSION = '0.006';
 use 5.010;
 use strict;
 use warnings;
@@ -424,7 +424,7 @@ sub __collect_internal_conf {
     # if YARN, use a different property. the oozie syntax doesn't change (still
     # uses the jobtracker property)
     $config->{jobTracker}     = $config->{resourceManager};
-    $config->{nameNode}     //= 'hdfs://nameservice1';
+    $config->{nameNode}     //= $self->template_namenode;
 
     $config->{has_sla}        = $self->sla;
 
@@ -1186,7 +1186,7 @@ App::Oozie::Deploy
 
 =head1 VERSION
 
-version 0.005
+version 0.006
 
 =head1 SYNOPSIS
 
