@@ -1,5 +1,5 @@
 package App::Oozie::Run;
-$App::Oozie::Run::VERSION = '0.005';
+$App::Oozie::Run::VERSION = '0.006';
 use 5.010;
 use strict;
 use warnings;
@@ -500,7 +500,7 @@ sub collect_oozie_cmd_args {
                                         startmin
                                     );
 
-    my $nameNode = $prop{nameNode} || 'hdfs://nameservice1';
+    my $nameNode = $prop{nameNode} || $self->template_namenode;
 
     my %cmd_param = (
         app_name      => $self->appname,
@@ -954,7 +954,7 @@ App::Oozie::Run
 
 =head1 VERSION
 
-version 0.005
+version 0.006
 
 =head1 SYNOPSIS
 
